@@ -1,6 +1,7 @@
 package Starch::Factory;
-
-$Starch::Factory::VERSION = '0.10';
+use 5.008001;
+use strictures 2;
+our $VERSION = '0.11';
 
 =head1 NAME
 
@@ -27,7 +28,6 @@ use Starch::Manager;
 use Starch::State;
 
 use Moo;
-use strictures 2;
 use namespace::clean;
 
 with qw(
