@@ -1,6 +1,7 @@
 package Starch::Plugin::AlwaysLoad;
-
-$Starch::Plugin::AlwaysLoad::VERSION = '0.10';
+use 5.008001;
+use strictures 2;
+our $VERSION = '0.11';
 
 =head1 NAME
 
@@ -23,7 +24,6 @@ accessed.
 =cut
 
 use Moo::Role;
-use strictures 2;
 use namespace::clean;
 
 with qw(
