@@ -1,13 +1,13 @@
 package Starch::Plugin::CookieArgs::Manager;
-
-$Starch::Plugin::CookieArgs::Manager::VERSION = '0.10';
+use 5.008001;
+use strictures 2;
+our $VERSION = '0.11';
 
 use Types::Standard -types;
 use Types::Common::String -types;
 use Types::Common::Numeric -types;
 
 use Moo::Role;
-use strictures 2;
 use namespace::clean;
 
 with qw(
