@@ -1,12 +1,12 @@
 package Starch::Plugin::RenewExpiration::Manager;
-
-$Starch::Plugin::RenewExpiration::Manager::VERSION = '0.10';
+use 5.008001;
+use strictures 2;
+our $VERSION = '0.11';
 
 use Types::Common::String -types;
 use Types::Common::Numeric -types;
 
 use Moo::Role;
-use strictures 2;
 use namespace::clean;
 
 with qw(
