@@ -1,6 +1,7 @@
 package Starch::Plugin::ThrottleStore;
-
-$Starch::Plugin::ThrottleStore::VERSION = '0.10';
+use 5.008001;
+use strictures 2;
+our $VERSION = '0.11';
 
 =head1 NAME
 
@@ -37,7 +38,6 @@ use Types::Common::Numeric -types;
 use Try::Tiny;
 
 use Moo::Role;
-use strictures 2;
 use namespace::clean;
 
 with qw(
