@@ -1,9 +1,9 @@
 package Starch::Plugin::Trace::Manager;
-
-$Starch::Plugin::Trace::Manager::VERSION = '0.10';
+use 5.008001;
+use strictures 2;
+our $VERSION = '0.11';
 
 use Moo::Role;
-use strictures 2;
 use namespace::clean;
 
 with qw(
