@@ -1,6 +1,7 @@
 package Starch::Role::Log;
-
-$Starch::Role::Log::VERSION = '0.10';
+use 5.008001;
+use strictures 2;
+our $VERSION = '0.11';
 
 =head1 NAME
 
@@ -12,7 +13,6 @@ use Types::Standard -types;
 use Log::Any;
 
 use Moo::Role;
-use strictures 2;
 use namespace::clean;
 
 =head1 ATTRIBUTES
