@@ -1,6 +1,7 @@
 package Starch::Store::Layered;
-
-$Starch::Store::Layered::VERSION = '0.10';
+use 5.008001;
+use strictures 2;
+our $VERSION = '0.11';
 
 =head1 NAME
 
@@ -55,7 +56,6 @@ use Types::Standard -types;
 use Scalar::Util qw( blessed );
 
 use Moo;
-use strictures 2;
 use namespace::clean;
 
 with qw(
