@@ -1,6 +1,7 @@
 package Starch::Store::Memory;
-
-$Starch::Store::Memory::VERSION = '0.10';
+use 5.008001;
+use strictures 2;
+our $VERSION = '0.11';
 
 =head1 NAME
 
@@ -18,7 +19,6 @@ use Types::Standard -types;
 use Types::Common::Numeric -types;
 
 use Moo;
-use strictures 2;
 use namespace::clean;
 
 with qw(
